==> wp_de_2.2.3.orig.zip: wordpress/wp-admin/setup-config.php <==
<?php
define('WP_INSTALLING', true);

if (!file_exists('../wp-config-sample.php'))
	die('Entschuldige, aber die Datei <code>wp-config-sample.php</code> wird f&uuml;r die Installation ben&ouml;tigt. Bitte lade diese Datei hoch.');

$configFile = file('../wp-config-sample.php');

if (!is_writable('../')) die("Entschuldige, aber dieses Verzeichnis ist nicht beschreibbar. Du wirst entweder die Schreibrechte Deines WordPress-Verzeichnisses &#228;ndern oder Deine <code>wp-config.php</code> manuell erstellen m&#252;ssen.");


if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;
header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>WordPress &rsaquo; Setup der Konfigurations-Datei<</title>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<style media="screen" type="text/css">
	<!--
	html {
		background: #eee;
	}
	body {
		background: #fff;
		color: #000;
		font-family: Georgia, "Times New Roman", Times, serif;
		margin-left: 20%;
		margin-right: 20%;
		padding: .2em 2em;
	}

	h1 {
		color: #006;
		font-size: 18px;
		font-weight: lighter;
	}

	h2 {
		font-size: 16px;
	}

	p, li, dt {
		line-height: 140%;
		padding-bottom: 2px;
	}

	ul, ol {
		padding: 5px 5px 5px 20px;
	}
	#logo {
		margin-bottom: 2em;
	}
	.step a, .step input {
		font-size: 2em;
	}
	td input {
		font-size: 1.5em;
	}
	.step, th {
		text-align: right;
	}
	#footer {
		text-align: center;
		border-top: 1px solid #ccc;
		padding-top: 1em;
		font-style: italic;
	}
	-->
	</style>
</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
// Check if wp-config.php has been created
if (file_exists('../wp-config.php'))
	die("<p>Die Datei <code>wp-config.php</code> existiert bereits. Wenn Du die Angaben &auml;ndern m&ouml;chtest, muss Du die Datei vorher l&ouml;schen. Du kannst jetzt die <a href='install.php'>Installation versuchen</a>.</p></body></html>");

switch($step) {
	case 0:
?>

<p>Willkommen bei WordPress. Bevor wir anfangen k&#246;nnen, ben&#246;tigen wir ein paar Informationen &#252;ber Deine Datenbank. Die folgenden Informationen solltest du parat haben:</p>
<ol>
  <li>Name der Datenbank</li>
  <li>Benutzername der Datenbank</li>
  <li>Passwort der Datenbank</li>
  <li>Datenbank-Host (<em>MySQL-Serveradresse</em>)</li>
  <li>Tabellen-Pr&#228;fix (<em>Wenn Du auch andere Scripte oder mehrere WordPress-Installationen &#252;ber eine Datenbank laufen lassen m&#246;chtest.</em>) </li>
</ol>
<p><strong>Wenn aus irgendeinem Grund die automatische Generierung der Dateien nicht funktioniert... keine Panik! Alles was wir hier machen, ist die oben angegebene Information an die Konfigurations-Datei zu &#252;bergeben. Alternativ kannst Du auch die <code>wp-config-sample.php</code> in einem Text-Editor &#246;ffnen, die ben&#246;tigte Information dort eingeben und die Datei als <code>wp-config.php</code> speichern.</strong></p>
<p>Die notwendigen Informationen hast du von deinem Provider bekommen. Wenn du sie nicht mehr hast, wirst du deinen Provider kontaktieren m&#252;ssen, bevor wir fortfahren k&#246;nnen.
<br />
<br />
Wenn alles klar ist, <a href="setup-config.php?step=1">dann kann es jetzt losgehen!</a></p>
<?php
	break;

	case 1:
	?>
</p>
<form method="post" action="setup-config.php?step=2">
	<p>Hier musst Du die Angaben zu Deiner Datenbankverbindung machen. Wenn Du dir nicht sicher bist, kontaktiere Deinen Provider.</p>
  <table>
    <tr>
      <th scope="row">Name der Datenbank</th>
      <td><input name="dbname" type="text" size="25" value="wordpress" /></td>
      <td>Der Name der Datenbank unter der WordPress laufen soll.</td>
    </tr>
    <tr>
      <th scope="row">Benutzer Name</th>
      <td><input name="uname" type="text" size="25" value="username" /></td>
      <td>Dein MySQL-Benutzername</td>
    </tr>
    <tr>
      <th scope="row">Passwort</th>
      <td><input name="pwd" type="text" size="25" value="password" /></td>
      <td>...und MySQL Passwort.</td>
    </tr>
    <tr>
      <th scope="row">Datenbank Host</th>
      <td><input name="dbhost" type="text" size="25" value="localhost" /></td>
      <td>mit 99%iger Wahrscheinlichkeit musst Du dies nicht &#228;ndern. (<em>MySQL-Serveradresse</em>)</td>
    </tr>
    <tr>
      <th scope="row">Tabellen-Pr&#228;fix</th>
      <td><input name="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
      <td>&Auml;ndere das Pr&#228;fix wenn Du andere Scripte oder mehrere WordPress-Installationen &#252;ber Deine Datenbank laufen lassen m&#246;chtest.</td>
    </tr>
  </table>
  <h2 class="step">
  <input name="submit" type="submit" value="absenden" />
  </h2>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if (empty($prefix)) $prefix = 'wp_';

	// Test the db connection.
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);

	// We'll fail here if the values are no good.
	require_once('../wp-includes/wp-db.php');
	$handle = fopen('../wp-config.php', 'w');

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				fwrite($handle, str_replace("putyourdbnamehere", $dbname, $line));
				break;
			case "define('DB_USER'":
				fwrite($handle, str_replace("'usernamehere'", "'$uname'", $line));
				break;
			case "define('DB_PASSW":
				fwrite($handle, str_replace("'yourpasswordhere'", "'$passwrd'", $line));
				break;
			case "define('DB_HOST'":
				fwrite($handle, str_replace("localhost", $dbhost, $line));
				break;
			case '$table_prefix  =':
				fwrite($handle, str_replace('wp_', $prefix, $line));
				break;
			default:
				fwrite($handle, $line);
		}
	}
	fclose($handle);
	chmod('../wp-config.php', 0666);
?>
<p>Alles klar! Du bist durch den wichtigsten Teil der Installation gekommen. WordPress kann nun mit Deiner Datenbank kommunizieren. Wenn Du bereit bist, <a href="install.php">starten wir die Installation!</a></p>
<?php
	break;
}
?>
<p id="footer"><a href="http://wordpress.org/">WordPress</a>, die moderne Publikationsplattform.</p>
</body>
</html>

==> wp_de_2.3.zip: wordpress/wp-admin/setup-config.php <==
<?php
define('WP_INSTALLING', true);

require_once('../wp-includes/compat.php');
require_once('../wp-includes/functions.php');

if (!file_exists('../wp-config-sample.php'))
	wp_die('Entschuldige, aber die Datei <code>wp-config-sample.php</code> wird f&uuml;r die Installation ben&ouml;tigt. Bitte lade diese Datei hoch.');

$configFile = file('../wp-config-sample.php');

if ( !is_writable('../')) 
	wp_die("Entschuldige, aber dieses Verzeichnis ist nicht beschreibbar. Du wirst entweder die Schreibrechte Deines WordPress-Verzeichnisses &#228;ndern oder Deine <code>wp-config.php</code> manuell erstellen m&#252;ssen.");

// Check if wp-config.php has been created
if (file_exists('../wp-config.php'))
	wp_die("<p>Die Datei <code>wp-config.php</code> existiert bereits. Wenn Du die Angaben &auml;ndern m&ouml;chtest, muss Du die Datei vorher l&ouml;schen. Du kannst jetzt die <a href='install.php'>Installation versuchen</a>.</p>");

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

function display_header(){
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>WordPress &rsaquo; Setup der Konfigurations-Datei</title>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<style media="screen" type="text/css">
	<!--
	html {
		background: #eee;
	}
	body {
		background: #fff;
		color: #000;
		font-family: Georgia, "Times New Roman", Times, serif;
		margin-left: 10%;
		margin-right: 10%;
		padding: .2em 2em;
	}

	h1 {
		color: #006;
		font-size: 18px;
		font-weight: lighter;
	}

	h2 {
		font-size: 16px;
	}

	p, li, dt {
		line-height: 140%;
		padding-bottom: 2px;
	}

	ul, ol {
		padding: 5px 5px 5px 20px;
	}
	#logo {
		margin-bottom: 2em;
	}
	.step a, .step input {
		font-size: 2em;
	}
	td input {
		font-size: 1.5em;
	}
	.step, th {
		text-align: right;
	}
	#footer {
		text-align: center;
		border-top: 1px solid #ccc;
		padding-top: 1em;
		font-style: italic;
	}
	-->
	</style>
</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>Willkommen bei WordPress. Bevor wir anfangen k&#246;nnen, ben&#246;tigen wir ein paar Informationen &#252;ber Deine Datenbank. Die folgenden Informationen solltest du parat haben:</p>
<ol>
  <li>Name der Datenbank</li>
  <li>Benutzername der Datenbank</li>
  <li>Passwort der Datenbank</li>
  <li>Datenbank-Host (<em>MySQL-Serveradresse</em>)</li>
  <li>Tabellen-Pr&#228;fix (<em>Wenn Du auch andere Scripte oder mehrere WordPress-Installationen &#252;ber eine Datenbank laufen lassen m&#246;chtest.</em>) </li>
</ol>
<p><strong>Wenn aus irgendeinem Grund die automatische Generierung der Dateien nicht funktioniert... keine Panik! Alles was wir hier machen, ist die oben angegebene Information an die Konfigurations-Datei zu &#252;bergeben. Alternativ kannst Du auch die <code>wp-config-sample.php</code> in einem Text-Editor &#246;ffnen, die ben&#246;tigte Information dort eingeben und die Datei als <code>wp-config.php</code> speichern.</strong></p>
<p>Die notwendigen Informationen hast du von deinem Provider bekommen. Wenn du sie nicht mehr hast, wirst du deinen Provider kontaktieren m&#252;ssen, bevor wir fortfahren k&#246;nnen.
<br />
<br />
Wenn alles klar ist, <a href="setup-config.php?step=1">dann kann es jetzt losgehen!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
</p>
<form method="post" action="setup-config.php?step=2">
	<p>Hier musst Du die Angaben zu Deiner Datenbankverbindung einsetzen. Wenn Du dir nicht sicher bist, kontaktiere Deinen Provider.</p>
  <table>
    <tr>
      <th scope="row">Name der Datenbank</th>
      <td><input name="dbname" type="text" size="25" value="wordpress" /></td>
      <td>Der Name der Datenbank unter der WordPress laufen soll.</td>
    </tr>
    <tr>
      <th scope="row">Benutzer Name</th>
      <td><input name="uname" type="text" size="25" value="username" /></td>
      <td>Dein MySQL-Benutzername</td>
    </tr>
    <tr>
      <th scope="row">Passwort</th>
      <td><input name="pwd" type="text" size="25" value="password" /></td>
      <td>...und MySQL Passwort.</td>
    </tr>
    <tr>
      <th scope="row">Datenbank Host</th>
      <td><input name="dbhost" type="text" size="25" value="localhost" /></td>
      <td>mit 99%iger Wahrscheinlichkeit musst Du dies nicht &#228;ndern. (<em>MySQL-Serveradresse</em>)</td>
    </tr>
    <tr>
      <th scope="row">Tabellen-Pr&#228;fix</th>
      <td><input name="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
      <td>&auml;ndere das Pr&#228;fix wenn Du andere Scripte oder mehrere WordPress-Installationen &#252;ber Deine Datenbank laufen lassen m&#246;chtest.</td>
    </tr>
  </table>
	<h2 class="step">
	<input name="submit" type="submit" value="Absenden" />
	</h2>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if (empty($prefix)) $prefix = 'wp_';

	// Test the db connection.
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);

	// We'll fail here if the values are no good.
	require_once('../wp-includes/wp-db.php');
	$handle = fopen('../wp-config.php', 'w');

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				fwrite($handle, str_replace("putyourdbnamehere", $dbname, $line));
				break;
			case "define('DB_USER'":
				fwrite($handle, str_replace("'usernamehere'", "'$uname'", $line));
				break;
			case "define('DB_PASSW":
				fwrite($handle, str_replace("'yourpasswordhere'", "'$passwrd'", $line));
				break;
			case "define('DB_HOST'":
				fwrite($handle, str_replace("localhost", $dbhost, $line));
				break;
			case '$table_prefix  =':
				fwrite($handle, str_replace('wp_', $prefix, $line));
				break;
			default:
				fwrite($handle, $line);
		}
	}
	fclose($handle);
	chmod('../wp-config.php', 0666);
	
	display_header();
?>
<p>Alles klar! Du bist durch den wichtigsten Teil der Installation gekommen. WordPress kann nun mit Deiner Datenbank kommunizieren. Wenn Du bereit bist, <a href="install.php">starten wir die Installation!</a></p>
<?php
	break;
}
?>
<p id="footer"><a href="http://wordpress.org/">WordPress</a>, die moderne Publikationsplattform.</p>
</body>
</html>
